#delimit ;
cd "" ;
set linesize 200;


/***** MAKE FIGURE 1, FIGURE 2 *****/

use dwnominate_trends_dataset, clear;

scatter gap_party_means year, c(l) lcolor(gs10) mcolor(black)
	xlabel(1870(20)2010) ylabel(.4(.1)1.1, nogrid) 
	yscale(range(.35 1.15))
	xtitle("Year") ytitle("Gap Between Party Means")
	plotregion(style(none)) graphregion(fcolor(white) lcolor(white));
graph export "figures_and_tables/dwnom_rc_1.pdf", replace;
graph export "figures_and_tables/dwnom_rc_1.eps", replace;

drop if year < 1976;
scatter d_mean_dwnom1 r_mean_dwnom1 year, c(l l) lcolor(dknavy maroon) mcolor(dknavy maroon)
	xlabel(1980(10)2010) ylabel(-.4(.2).8, nogrid) legend(off)
	yline(0, lc(gs10))
	xtitle("Year") ytitle("Average Score Within Party")
	plotregion(style(none)) graphregion(fcolor(white) lcolor(white))
	text(-.22 1980 "Democrats", col(dknavy))
	text(0.65 2000 "Republicans", col(maroon));
graph export "figures_and_tables/dwnom_rc_party_means.pdf", replace;


/***** MAKE FIGURE 3 *****/

use npat_scores_dataset, clear;
drop if idno == .;
gen num_scores = 1;
collapse (mean) npat_wnom1 (sum) num_scores, by(idno);
replace num_scores = 2 if num_scores > 2 & num_scores != .;
save tmp1, replace;

use rollcall_scores_dataset, clear;
merge m:1 idno using tmp1;
replace num_scores = 0 if _merge == 1;
drop if _merge == 2;
drop _merge;
keep if year >= 1996 & year <= 2008;
gen dwnom_D   = rc_dwnom1 if party == 100;
gen dwnom_D_1 = rc_dwnom1 if party == 100 & num_scores >= 1;
gen dwnom_D_2 = rc_dwnom1 if party == 100 & num_scores == 2;
gen dwnom_R   = rc_dwnom1 if party == 200;
gen dwnom_R_1 = rc_dwnom1 if party == 200 & num_scores >= 1;
gen dwnom_R_2 = rc_dwnom1 if party == 200 & num_scores == 2;
collapse (mean) dwnom_*, by(year);
gen gap   = dwnom_R   - dwnom_D;
gen gap_1 = dwnom_R_1 - dwnom_D_1;
gen gap_2 = dwnom_R_2 - dwnom_D_2;
label var gap   "All MCs";
label var gap_1 "MCs with 1  NPAT Score";
label var gap_2 "MCs with 2+ NPAT Scores";

scatter gap gap_1 gap_2 year, 
	c(l l l) lcolor(gs10 gs7 gs0) mcolor(gs10 gs7 gs0) m(O S T)
	lpattern(solid shortdash solid) legend(off)
	plotregion(style(none)) graphregion(fcolor(white) lcolor(white))
	text(1.015 2001.8 "MCs with 2+ NPAT Scores" 0.935 2002.8 "All MCs")
	xlabel(1996 1998 2000 2002 2004 2006 2008) ylabel(.85(.05)1.05, nogrid) 
	xtitle("Year") ytitle("Gap Between Party Means");
graph export "figures_and_tables/rc_dwnom_2.pdf", replace;

/* report the size of the change for All MCs, MCs with 1 NPAT Score, and MCs with 2+ NPAT Scores */
foreach var of varlist gap gap_1 gap_2{;
	di `var'[7] - `var'[1];
};


/***** MAKE FIGURE 4, FIGURE 5, TABLE 1, AND CORRESPONDING APPENDIX TABLES ON MOVING OVER TIME *****/

use npat_scores_dataset, clear;
sort npat_id year party;
foreach i in wnom1 linp {;
	gen npat_`i'_next_2   = npat_`i'[_n+1] if npat_id == npat_id[_n+1] & year == year[_n+1] - 2;
	gen npat_`i'_diff_2   = npat_`i'_next_2 - npat_`i';
	gen npat_`i'_next_any = npat_`i'[_n+1] if npat_id == npat_id[_n+1] & year <= year[_n+1] - 2;
	gen npat_`i'_diff_any = npat_`i'_next_any - npat_`i';
};
foreach i in trichotomous nonexpanded_v1 nonexpanded_v2 nonexpanded_v3 nonexpanded_v4 {;
	gen npat_wnom1_`i'_n_2   = npat_wnom1_`i'[_n+1] if npat_id == npat_id[_n+1] & year == year[_n+1] - 2;
	gen npat_wnom1_`i'_d_2   = npat_wnom1_`i'_n_2 - npat_wnom1_`i';
	gen npat_wnom1_`i'_n_any = npat_wnom1_`i'[_n+1] if npat_id == npat_id[_n+1] & year <= year[_n+1] - 2;
	gen npat_wnom1_`i'_d_any = npat_wnom1_`i'_n_any - npat_wnom1_`i';
};
rename name name_2;
rename party party_2;
sort npat_id year;
save tmp1, replace;


/***** FIGURE 4 *****/

use tmp1, clear;
drop if npat_wnom1_diff_2 ==. & npat_wnom1_diff_any == .;
sort npat_wnom1 npat_wnom1_next_2;
scatter npat_wnom1_next_2 npat_wnom1 npat_wnom1,
	ms(i i) mlab(party) mlabpos(0 0) c(. l) lcolor(gs0 gs10) mcolor(gs0 gs10) mlabcolor(gs0 gs10)
	plotregion(style(none)) graphregion(fcolor(white) lcolor(white))
	xtitle(Score in Year 1) ytitle(Score in Year 2) 
	xlabel(`xylabels') ylabel(`xylabels', nogrid) 
	xscale(range(`min12' `max12')) yscale(range(`min12' `max12')) 
	legend(off) aspectratio(1);
graph export "figures_and_tables/npat_wnom1_year2_vs_year1_all.pdf", replace;


/***** APPENDIX FIGURE A.5, CONSERVATIVE LIN PROB SCORES *****/

use tmp1, clear;
drop if npat_linp_diff_2 ==. & npat_linp_diff_any == .;
sort npat_linp npat_linp_next_2;
scatter npat_linp_next_2 npat_linp npat_linp,
	ms(i i) mlab(party) mlabpos(0 0) c(. l) lcolor(gs0 gs10) mcolor(gs0 gs10) mlabcolor(gs0 gs10)
	plotregion(style(none)) graphregion(fcolor(white) lcolor(white))
	xtitle(Score in Year 1) ytitle(Score in Year 2) 
	xlabel(`xylabels') ylabel(`xylabels', nogrid) 
	xscale(range(`min12' `max12')) yscale(range(`min12' `max12')) 
	legend(off) aspectratio(1);
graph export "appendix_figures_and_tables/npat_linp_year2_vs_year1_all.pdf", replace;


/***** APPENDIX FIGURE A.6, MCs ONLY *****/

use tmp1, clear;
drop if npat_linp_diff_2 == . & npat_linp_diff_any == .;
drop if idno == .;
sort npat_wnom1 npat_wnom1_next_2;
scatter npat_wnom1_next_2 npat_wnom1 npat_wnom1,
	ms(i i) mlab(party) mlabpos(0 0) c(. l) lcolor(gs0 gs10) mcolor(gs0 gs10) mlabcolor(gs0 gs10)
	plotregion(style(none)) graphregion(fcolor(white) lcolor(white))
	xtitle(Score in Year 1) ytitle(Score in Year 2) 
	xlabel(`xylabels') ylabel(`xylabels', nogrid) 
	xscale(range(`min12' `max12')) yscale(range(`min12' `max12')) 
	legend(off) aspectratio(1);
graph export "appendix_figures_and_tables/npat_wnom1_year2_vs_year1_MC.pdf", replace;


/***** FIGURE 5 *****/

forvalues i = 1996(2)2006 {;
	local ii = `i' + 2;
	use tmp1, clear;
	drop if npat_wnom1_diff_2 ==. & npat_wnom1_diff_any == .;
	keep if year == `i';
	sort npat_wnom1 npat_wnom1_next_2;
	scatter npat_wnom1_next_2 npat_wnom1 npat_wnom1,
		ms(i i) mlab(party) mlabpos(0 0) c(. l) lcolor(gs0 gs10) mcolor(gs0 gs10) mlabcolor(gs0 gs10)
		plotregion(style(none)) graphregion(fcolor(white) lcolor(white))
		xtitle(Score in Year 1) ytitle(Score in Year 2) 
		xlabel(`xylabels') ylabel(`xylabels', nogrid) 
		xscale(range(`min12' `max12')) yscale(range(`min12' `max12')) 
		legend(off) aspectratio(1);
	graph export "figures_and_tables/npat_wnom1_year2_vs_year1_`i'_`ii'.pdf", replace;
};


/***** TABLE 1 *****/

use tmp1, clear;
ttest npat_wnom1_diff_2   = 0;
 local m_all_2_wnom = r(mu_1);
 local n_all_2_wnom = r(N_1);
 local t_all_2_wnom = r(t);
ttest npat_wnom1_diff_any = 0;
 local m_all_a_wnom = r(mu_1);
 local n_all_a_wnom = r(N_1);
 local t_all_a_wnom = r(t);
ttest npat_wnom1_diff_2   = 0 if party == "R";
 local m_all_2_R_wnom = r(mu_1);
 local n_all_2_R_wnom = r(N_1);
 local t_all_2_R_wnom = r(t);
ttest npat_wnom1_diff_any = 0 if party == "R";
 local m_all_a_R_wnom = r(mu_1);
 local n_all_a_R_wnom = r(N_1);
 local t_all_a_R_wnom = r(t);
ttest npat_wnom1_diff_2   = 0 if party == "D";
 local m_all_2_D_wnom = r(mu_1);
 local n_all_2_D_wnom = r(N_1);
 local t_all_2_D_wnom = r(t);
ttest npat_wnom1_diff_any = 0 if party == "D";
 local m_all_a_D_wnom = r(mu_1);
 local n_all_a_D_wnom = r(N_1);
 local t_all_a_D_wnom = r(t);

quietly {;
	capture log close;
	log using figures_and_tables/table_t_tests_1.tex, text replace;
	noisily display "\begin{table}[htbp] ";
	noisily display "\centering ";
	noisily display "\begin{threeparttable} ";
	noisily display "\caption{\bf Do Candidates Change NPAT Scores Over Time?} ";
	noisily display "\label{table_t_tests_1} ";
	noisily display "\begin{tabular}{lccc} ";
	noisily display "\toprule ";
	noisily display "Case & Difference & t-Statistic & \# Obs. \\ [.01in] ";
	noisily display "\midrule ";
	noisily display "\multicolumn{4}{l}{\it Both major parties} \\ [.01in] "; 
	noisily display "Year 2 $-$ Year 1 $=$   2 & " %5.3f `m_all_2_wnom'   " & " %5.3f `t_all_2_wnom'   " & " %3.0f `n_all_2_wnom'   " \\ ";  
	noisily display "Year 2 $-$ Year 1 $\ge$ 2 & " %5.3f `m_all_a_wnom'   " & " %5.3f `t_all_a_wnom'   " & " %3.0f `n_all_a_wnom'   " \\ ";  
	noisily display "\midrule ";
	noisily display "\multicolumn{4}{l}{\it Republicans} \\ [.01in] "; 
	noisily display "Year 2 $-$ Year 1 $=$   2 & " %5.3f `m_all_2_R_wnom' " & " %5.3f `t_all_2_R_wnom' " & " %3.0f `n_all_2_R_wnom' " \\ ";  
	noisily display "Year 2 $-$ Year 1 $\ge$ 2 & " %5.3f `m_all_a_R_wnom' " & " %5.3f `t_all_a_R_wnom' " & " %3.0f `n_all_a_R_wnom' " \\ ";  
	noisily display "\midrule ";
	noisily display "\multicolumn{4}{l}{\it Democrats} \\ [.01in] "; 
	noisily display "Year 2 $-$ Year 1 $=$   2 & " %5.3f `m_all_2_D_wnom' " & " %5.3f `t_all_2_D_wnom' " & " %3.0f `n_all_2_D_wnom' " \\ ";  
	noisily display "Year 2 $-$ Year 1 $\ge$ 2 & " %5.3f `m_all_a_D_wnom' " & " %5.3f `t_all_a_D_wnom' " & " %3.0f `n_all_a_D_wnom' " \\ ";  
	noisily display "\bottomrule ";
	noisily display "\end{tabular}";
	noisily display "\end{threeparttable} ";
	noisily display "\end{table} ";
	log close;
};


/***** APPENDIX TABLE A.6 (LINEAR CONSERVATIVE PROBABILITY SCORES) *****/

use tmp1, clear;
ttest npat_linp_diff_2   = 0;
 local m_all_2_linp = r(mu_1);
 local n_all_2_linp = r(N_1);
 local t_all_2_linp = r(t);
ttest npat_linp_diff_any = 0;
 local m_all_a_linp = r(mu_1);
 local n_all_a_linp = r(N_1);
 local t_all_a_linp = r(t);
ttest npat_linp_diff_2   = 0 if party == "R";
 local m_all_2_R_linp = r(mu_1);
 local n_all_2_R_linp = r(N_1);
 local t_all_2_R_linp = r(t);
ttest npat_linp_diff_any = 0 if party == "R";
 local m_all_a_R_linp = r(mu_1);
 local n_all_a_R_linp = r(N_1);
 local t_all_a_R_linp = r(t);
ttest npat_linp_diff_2   = 0 if party == "D";
 local m_all_2_D_linp = r(mu_1);
 local n_all_2_D_linp = r(N_1);
 local t_all_2_D_linp = r(t);
ttest npat_linp_diff_any = 0 if party == "D";
 local m_all_a_D_linp = r(mu_1);
 local n_all_a_D_linp = r(N_1);
 local t_all_a_D_linp = r(t);

quietly {;
	capture log close;
	log using appendix_figures_and_tables/table_t_tests_1_appendix_linp.tex, text replace;
	noisily display "\begin{table}[htbp] ";
	noisily display "\centering ";
	noisily display "\begin{threeparttable} ";
	noisily display "\caption{\bf Do Candidates Change NPAT Scores Over Time? \\ (Linear Conservative Probability Scores)} ";
	noisily display "\label{table_t_tests_1_appendix_linp} ";
	noisily display "\begin{tabular}{lccc} ";
	noisily display "\toprule ";
	noisily display "Case & Difference & t-Statistic & \# Obs. \\ [.01in] ";
	noisily display "\midrule ";
	noisily display "\multicolumn{4}{l}{\it Both major parties} \\ [.01in] "; 
	noisily display "Year 2 $-$ Year 1 $=$   2 & " %5.3f `m_all_2_linp'   " & " %5.3f `t_all_2_linp'   " & " %3.0f `n_all_2_linp'   " \\ ";  
	noisily display "Year 2 $-$ Year 1 $\ge$ 2 & " %5.3f `m_all_a_linp'   " & " %5.3f `t_all_a_linp'   " & " %3.0f `n_all_a_linp'   " \\ ";  
	noisily display "\midrule ";
	noisily display "\multicolumn{4}{l}{\it Republicans} \\ [.01in] "; 
	noisily display "Year 2 $-$ Year 1 $=$   2 & " %5.3f `m_all_2_R_linp' " & " %5.3f `t_all_2_R_linp' " & " %3.0f `n_all_2_R_linp' " \\ ";  
	noisily display "Year 2 $-$ Year 1 $\ge$ 2 & " %5.3f `m_all_a_R_linp' " & " %5.3f `t_all_a_R_linp' " & " %3.0f `n_all_a_R_linp' " \\ ";  
	noisily display "\midrule ";
	noisily display "\multicolumn{4}{l}{\it Democrats} \\ [.01in] "; 
	noisily display "Year 2 $-$ Year 1 $=$   2 & " %5.3f `m_all_2_D_linp' " & " %5.3f `t_all_2_D_linp' " & " %3.0f `n_all_2_D_linp' " \\ ";  
	noisily display "Year 2 $-$ Year 1 $\ge$ 2 & " %5.3f `m_all_a_D_linp' " & " %5.3f `t_all_a_D_linp' " & " %3.0f `n_all_a_D_linp' " \\ ";  
	noisily display "\bottomrule ";
	noisily display "\end{tabular}";
	noisily display "\end{threeparttable} ";
	noisily display "\end{table} ";
	log close;
};


/***** APPENDIX TABLE A.9 (RESTRICTED TO CANDIDATES WHO SERVED IN CONGRESS) *****/

use tmp1, clear;
drop if npat_wnom1_diff_2 ==. & npat_wnom1_diff_any == .;
drop if idno == .;
ttest npat_wnom1_diff_2   = 0;
 local m_all_2 = r(mu_1);
 local n_all_2 = r(N_1);
 local t_all_2 = r(t);
ttest npat_wnom1_diff_any = 0;
 local m_all_a = r(mu_1);
 local n_all_a = r(N_1);
 local t_all_a = r(t);
ttest npat_wnom1_diff_2   = 0 if party == "R";
 local m_all_2_R = r(mu_1);
 local n_all_2_R = r(N_1);
 local t_all_2_R = r(t);
ttest npat_wnom1_diff_any = 0 if party == "R";
 local m_all_a_R = r(mu_1);
 local n_all_a_R = r(N_1);
 local t_all_a_R = r(t);
ttest npat_wnom1_diff_2   = 0 if party == "D";
 local m_all_2_D = r(mu_1);
 local n_all_2_D = r(N_1);
 local t_all_2_D = r(t);
ttest npat_wnom1_diff_any = 0 if party == "D";
 local m_all_a_D = r(mu_1);
 local n_all_a_D = r(N_1);
 local t_all_a_D = r(t);

quietly {;
	capture log close;
	log using appendix_figures_and_tables/table_t_tests_1_appendix_MC.tex, text replace;
	noisily display "\begin{table}[htbp] ";
	noisily display "\centering ";
	noisily display "\begin{threeparttable} ";
	noisily display "\caption{\bf Do Candidates Change NPAT Scores Over Time? Restrict Sample to Candidates Who Served in Congress} ";
	noisily display "\label{table_t_tests_1_appendix_MC} ";
	noisily display "\begin{tabular}{lccc} ";
	noisily display "\toprule ";
	noisily display "Case & Difference & t-Statistic & \# Obs. \\ [.01in] ";
	noisily display "\midrule ";
	noisily display "\multicolumn{4}{l}{\it Both major parties} \\ [.01in] "; 
	noisily display "Year 2 $-$ Year 1 $=$   2 & " %5.3f `m_all_2'   " & " %5.3f `t_all_2'   " & " %3.0f `n_all_2'   " \\ ";  
	noisily display "Year 2 $-$ Year 1 $\ge$ 2 & " %5.3f `m_all_a'   " & " %5.3f `t_all_a'   " & " %3.0f `n_all_a'   " \\ ";  
	noisily display "\midrule ";
	noisily display "\multicolumn{4}{l}{\it Republicans} \\ [.01in] "; 
	noisily display "Year 2 $-$ Year 1 $=$   2 & " %5.3f `m_all_2_R' " & " %5.3f `t_all_2_R' " & " %3.0f `n_all_2_R' " \\ ";  
	noisily display "Year 2 $-$ Year 1 $\ge$ 2 & " %5.3f `m_all_a_R' " & " %5.3f `t_all_a_R' " & " %3.0f `n_all_a_R' " \\ ";  
	noisily display "\midrule ";
	noisily display "\multicolumn{4}{l}{\it Democrats} \\ [.01in] "; 
	noisily display "Year 2 $-$ Year 1 $=$   2 & " %5.3f `m_all_2_D' " & " %5.3f `t_all_2_D' " & " %3.0f `n_all_2_D' " \\ ";  
	noisily display "Year 2 $-$ Year 1 $\ge$ 2 & " %5.3f `m_all_a_D' " & " %5.3f `t_all_a_D' " & " %3.0f `n_all_a_D' " \\ ";  
	noisily display "\bottomrule ";
	noisily display "\end{tabular}";
	noisily display "\end{threeparttable} ";
	noisily display "\end{table} ";
	log close;
};


/***** APPENDIX TABLE A.10 (DATA COLLAPSED SO THERE IS JUST 1 OBSERVATION PER CANDIDATE) *****/

use tmp1, clear;
drop if npat_wnom1_diff_2 ==. & npat_wnom1_diff_any == .;
collapse (mean) npat_wnom1_diff_*, by(state npat_id party);
ttest npat_wnom1_diff_2   = 0;
 local m_all_2 = r(mu_1);
 local n_all_2 = r(N_1);
 local t_all_2 = r(t);
ttest npat_wnom1_diff_any = 0;
 local m_all_a = r(mu_1);
 local n_all_a = r(N_1);
 local t_all_a = r(t);
ttest npat_wnom1_diff_2   = 0 if party == "R";
 local m_all_2_R = r(mu_1);
 local n_all_2_R = r(N_1);
 local t_all_2_R = r(t);
ttest npat_wnom1_diff_any = 0 if party == "R";
 local m_all_a_R= r(mu_1);
 local n_all_a_R = r(N_1);
 local t_all_a_R = r(t);
ttest npat_wnom1_diff_2   = 0 if party == "D";
 local m_all_2_D = r(mu_1);
 local n_all_2_D = r(N_1);
 local t_all_2_D = r(t);
ttest npat_wnom1_diff_any = 0 if party == "D";
 local m_all_a_D = r(mu_1);
 local n_all_a_D = r(N_1);
 local t_all_a_D = r(t);

quietly {;
	capture log close;
	log using appendix_figures_and_tables/table_t_tests_appendix_1_collapsed.tex, text replace;
	noisily display "\begin{table}[htbp] ";
	noisily display "\centering ";
	noisily display "\begin{threeparttable} ";
	noisily display "\caption{\bf Do Candidates Change NPAT Scores Over Time? Collapsed Data, One Observation per Candidate} ";
	noisily display "\label{table_t_tests_appendix_1_collapsed} ";
	noisily display "\begin{tabular}{lccc} ";
	noisily display "\toprule ";
	noisily display "Case & Difference & t-Statistic & \# Obs. \\ [.01in] ";
	noisily display "\midrule ";
	noisily display "\multicolumn{4}{l}{\it Both major parties} \\ [.01in] "; 
	noisily display "Year 2 $-$ Year 1 $=$   2 & " %5.3f `m_all_2'   " & " %5.3f `t_all_2'   " & " %3.0f `n_all_2'   " \\ ";  
	noisily display "Year 2 $-$ Year 1 $\ge$ 2 & " %5.3f `m_all_a'   " & " %5.3f `t_all_a'   " & " %3.0f `n_all_a'   " \\ ";  
	noisily display "\midrule ";
	noisily display "\multicolumn{4}{l}{\it Republicans} \\ [.01in] "; 
	noisily display "Year 2 $-$ Year 1 $=$   2 & " %5.3f `m_all_2_R' " & " %5.3f `t_all_2_R' " & " %3.0f `n_all_2_R' " \\ ";  
	noisily display "Year 2 $-$ Year 1 $\ge$ 2 & " %5.3f `m_all_a_R' " & " %5.3f `t_all_a_R' " & " %3.0f `n_all_a_R' " \\ ";  
	noisily display "\midrule ";
	noisily display "\multicolumn{4}{l}{\it Democrats} \\ [.01in] "; 
	noisily display "Year 2 $-$ Year 1 $=$   2 & " %5.3f `m_all_2_D' " & " %5.3f `t_all_2_D' " & " %3.0f `n_all_2_D' " \\ ";  
	noisily display "Year 2 $-$ Year 1 $\ge$ 2 & " %5.3f `m_all_a_D' " & " %5.3f `t_all_a_D' " & " %3.0f `n_all_a_D' " \\ ";  
	noisily display "\bottomrule ";
	noisily display "\end{tabular}";
	noisily display "\end{threeparttable} ";
	noisily display "\end{table} ";
	log close;
};


/***** APPENDIX TABLE A.3 (TRICHOTOMOUS AND 4 VERSIONS OF DICHOTOMOUS CODING OF LIKERT SCALE ITEMS) *****/

use tmp1, clear;

foreach i in trichotomous nonexpanded_v1 nonexpanded_v2 nonexpanded_v3 nonexpanded_v4 {;
	if "`i'" == "expanded" {;
		local t e;
	};
	if "`i'" == "trichotomous" {;
		local t t;
	};
	if "`i'" == "nonexpanded_v1" {;
		local t n1;
	};
	if "`i'" == "nonexpanded_v2" {;
		local t n2;
	};
	if "`i'" == "nonexpanded_v3" {;
		local t n3;
	};
	if "`i'" == "nonexpanded_v4" {;
		local t n4;
	};
	ttest npat_wnom1_`i'_d_2   = 0;
	 local m_all_2_`t' = r(mu_1);
	 local n_all_2_`t' = r(N_1);
	 local t_all_2_`t' = r(t);
	ttest npat_wnom1_`i'_d_any = 0;
	 local m_all_a_`t' = r(mu_1);
	 local n_all_a_`t' = r(N_1);
	 local t_all_a_`t' = r(t);
	ttest npat_wnom1_`i'_d_2   = 0 if party == "R";
	 local m_all_2_R_`t' = r(mu_1);
	 local n_all_2_R_`t' = r(N_1);
	 local t_all_2_R_`t' = r(t);
	ttest npat_wnom1_`i'_d_any = 0 if party == "R";
	 local m_all_a_R_`t' = r(mu_1);
	 local n_all_a_R_`t' = r(N_1);
	 local t_all_a_R_`t' = r(t);
	ttest npat_wnom1_`i'_d_2   = 0 if party == "D";
	 local m_all_2_D_`t' = r(mu_1);
	 local n_all_2_D_`t' = r(N_1);
	 local t_all_2_D_`t' = r(t);
	ttest npat_wnom1_`i'_d_any = 0 if party == "D";
	 local m_all_a_D_`t' = r(mu_1);
	 local n_all_a_D_`t' = r(N_1);
	 local t_all_a_D_`t' = r(t);
};

quietly {;
  capture log close;
  log using appendix_figures_and_tables/table_t_tests_1_appendix_codings.tex, text replace;

  noisily display "\begin{table}[htbp] ";
  noisily display "\centering ";
  noisily display "\caption{\bf Do Candidates Change NPAT Scores Over Time? \\ Alternative Coding Rules for Likert-Scale NPAT Questions} ";
  noisily display "\label{table_t_tests_1_appendix_codings} ";
  noisily display "\resizebox{\textwidth}{!}{ ";
  noisily display "\begin{tabular}{l cc cc cc cc cc c} ";
  noisily display "\toprule ";
  noisily display " & \multicolumn{2}{c}{Likert-to-} & \multicolumn{2}{c}{Likert-to-} & \multicolumn{2}{c}{Likert-to} & \multicolumn{2}{c}{Likert-to-} & \multicolumn{2}{c}{Likert-to-} & \\";
  noisily display " & \multicolumn{2}{c}{Trichot}    & \multicolumn{2}{c}{Binary 1}   & \multicolumn{2}{c}{Binary 2}  & \multicolumn{2}{c}{Binary 3}   & \multicolumn{2}{c}{Binary 4}   & \\";
  noisily display "Case & Diff & t-Stat & Diff & t-Stat & Diff & t-Stat & Diff & t-Stat & Diff & t-Stat & \# Obs. \\ [.01in] ";
  noisily display "\midrule ";

  noisily display "\multicolumn{4}{l}{\it Both major parties} \\ [.01in] "; 
  noisily display "Year 2 $-$ Year 1 $=$   2 & " %5.3f `m_all_2_t'   " & " %5.3f `t_all_2_t'   " & " %5.3f `m_all_2_n1'   " & " %5.3f `t_all_2_n1'   " & " %5.3f `m_all_2_n2'   " & " %5.3f `t_all_2_n2'   " & " %5.3f `m_all_2_n3'   " & " %5.3f `t_all_2_n3'   " & " %5.3f `m_all_2_n4'   " & " %5.3f `t_all_2_n4'   " & " %3.0f `n_all_2_t'   " \\ ";  
  noisily display "Year 2 $-$ Year 1 $\ge$ 2 & " %5.3f `m_all_a_t'   " & " %5.3f `t_all_a_t'   " & " %5.3f `m_all_a_n1'   " & " %5.3f `t_all_a_n1'   " & " %5.3f `m_all_a_n2'   " & " %5.3f `t_all_a_n2'   " & " %5.3f `m_all_a_n3'   " & " %5.3f `t_all_a_n3'   " & " %5.3f `m_all_a_n4'   " & " %5.3f `t_all_a_n4'   " & " %3.0f `n_all_a_t'   " \\ ";  

  noisily display "\midrule " ;
  noisily display "\multicolumn{4}{l}{\it Republicans} \\ [.01in] "; 
  noisily display "Year 2 $-$ Year 1 $=$   2 & " %5.3f `m_all_2_R_t' " & " %5.3f `t_all_2_R_t' " & " %5.3f `m_all_2_R_n1' " & " %5.3f `t_all_2_R_n1' " & " %5.3f `m_all_2_R_n2' " & " %5.3f `t_all_2_R_n2' " & " %5.3f `m_all_2_R_n3' " & " %5.3f `t_all_2_R_n3' " & " %5.3f `m_all_2_R_n4' " & " %5.3f `t_all_2_R_n4' " & " %3.0f `n_all_2_R_t' " \\ ";  
  noisily display "Year 2 $-$ Year 1 $\ge$ 2 & " %5.3f `m_all_a_R_t' " & " %5.3f `t_all_a_R_t' " & " %5.3f `m_all_a_R_n1' " & " %5.3f `t_all_a_R_n1' " & " %5.3f `m_all_a_R_n2' " & " %5.3f `t_all_a_R_n2' " & " %5.3f `m_all_a_R_n3' " & " %5.3f `t_all_a_R_n3' " & " %5.3f `m_all_a_R_n4' " & " %5.3f `t_all_a_R_n4' " & " %3.0f `n_all_a_R_t' " \\ ";  

  noisily display "\midrule " ;
  noisily display "\multicolumn{4}{l}{\it Democrats} \\ [.01in] "; 
  noisily display "Year 2 $-$ Year 1 $=$   2 & " %5.3f `m_all_2_D_t' " & " %5.3f `t_all_2_D_t' " & " %5.3f `m_all_2_D_n1' " & " %5.3f `t_all_2_D_n1' " & " %5.3f `m_all_2_D_n2' " & " %5.3f `t_all_2_D_n2' " & " %5.3f `m_all_2_D_n3' " & " %5.3f `t_all_2_D_n3' " & " %5.3f `m_all_2_D_n4' " & " %5.3f `t_all_2_D_n4' " & " %3.0f `n_all_2_D_t' " \\ ";  
  noisily display "Year 2 $-$ Year 1 $\ge$ 2 & " %5.3f `m_all_a_D_t' " & " %5.3f `t_all_a_D_t' " & " %5.3f `m_all_a_D_n1' " & " %5.3f `t_all_a_D_n1' " & " %5.3f `m_all_a_D_n2' " & " %5.3f `t_all_a_D_n2' " & " %5.3f `m_all_a_D_n3' " & " %5.3f `t_all_a_D_n3' " & " %5.3f `m_all_a_D_n4' " & " %5.3f `t_all_a_D_n4' " & " %3.0f `n_all_a_D_t' " \\ ";  

  noisily display "\bottomrule ";
  noisily display "\end{tabular} ";
  noisily display "} ";
  noisily display "\end{table} ";
  log close;
};


/***** CALCULATE QUANTITIES FOR TABLES 2 AND 4, AND FOR APPENDIX TABLE ANALOGOUS TO TABLE 2 *****/

use npat_scores_dataset, clear;
drop if idno == .;
keep idno npat_wnom1* npat_linp*;
collapse (mean) npat_wnom1* npat_linp*, by(idno);
save tmp1, replace;
use rollcall_scores_dataset, clear;
merge m:1 idno using tmp1;
sort idno;
keep if type == "1 leaver" | type == "2 joiner";
keep if year >= 1996 & year <= 2008;
collapse (mean) rc_dwnom1 npat_wnom1* npat_linp* minyear maxyear, by(state npat_id idno party type);
save tmp1, replace;

ttest rc_dwnom1  if party == 200 & (type == "2 joiner" | type == "1 leaver"), by(type);
 local m1_rc1_R = r(mu_1);
 local m2_rc1_R = r(mu_2);
 local d_rc1_R = r(mu_2) - r(mu_1);
 local n1_rc1_R = r(N_1);
 local n2_rc1_R = r(N_2);
 local t_rc1_R = -r(t);
ttest rc_dwnom1  if party == 200 & (type == "2 joiner" | type == "1 leaver") & npat_wnom1 != ., by(type);
 local m1_rc2_R = r(mu_1);
 local m2_rc2_R = r(mu_2);
 local d_rc2_R = r(mu_2) - r(mu_1);
 local n1_rc2_R = r(N_1);
 local n2_rc2_R = r(N_2);
 local t_rc2_R = -r(t);
ttest npat_wnom1 if party == 200 & (type == "2 joiner" | type == "1 leaver"), by(type);
 local m1_npat_R = r(mu_1);
 local m2_npat_R = r(mu_2);
 local d_npat_R = r(mu_2) - r(mu_1);
 local n1_npat_R = r(N_1);
 local n2_npat_R = r(N_2);
 local t_npat_R = -r(t);
ttest npat_linp if party == 200 & (type == "2 joiner" | type == "1 leaver"), by(type);
 local m1_linp_R = r(mu_1);
 local m2_linp_R = r(mu_2);
 local d_linp_R = r(mu_2) - r(mu_1);
 local n1_linp_R = r(N_1);
 local n2_linp_R = r(N_2);
 local t_linp_R = -r(t);
foreach i in trichotomous nonexpanded_v1 nonexpanded_v2 nonexpanded_v3 nonexpanded_v4 {;
	if "`i'" == "expanded" {;
		local t e;
	};
	if "`i'" == "trichotomous" {;
		local t t;
	};
	if "`i'" == "nonexpanded_v1" {;
		local t n1;
	};
	if "`i'" == "nonexpanded_v2" {;
		local t n2;
	};
	if "`i'" == "nonexpanded_v3" {;
		local t n3;
	};
	if "`i'" == "nonexpanded_v4" {;
		local t n4;
	};
	ttest npat_wnom1_`i' if party == 200 & (type == "2 joiner" | type == "1 leaver"), by(type);
	 local m1_npat_R_`t' = r(mu_1);
	 local m2_npat_R_`t' = r(mu_2);
	 local d_npat_R_`t' = r(mu_2) - r(mu_1);
	 local n1_npat_R_`t' = r(N_1);
	 local n2_npat_R_`t' = r(N_2);
	 local t_npat_R_`t' = -r(t);
};
foreach i in defense econ eduh envir other social {;
	ttest npat_linp_`i' if party == 200 & (type == "2 joiner" | type == "1 leaver"), by(type);
  	 local m1_`i'_R = r(mu_1);
  	 local m2_`i'_R = r(mu_2);
  	 local d_`i'_R = r(mu_2) - r(mu_1);
  	 local n1_`i'_R = r(N_1);
  	 local n2_`i'_R = r(N_2);
  	 local t_`i'_R = -r(t);
};
ttest rc_dwnom1  if party == 100 & (type == "2 joiner" | type == "1 leaver"), by(type);
 local m1_rc1_D = r(mu_1);
 local m2_rc1_D = r(mu_2);
 local d_rc1_D = r(mu_2) - r(mu_1);
 local n1_rc1_D = r(N_1);
 local n2_rc1_D = r(N_2);
 local t_rc1_D = -r(t);
ttest rc_dwnom1  if party == 100 & (type == "2 joiner" | type == "1 leaver") & npat_wnom1 != ., by(type);
 local m1_rc2_D = r(mu_1);
 local m2_rc2_D = r(mu_2);
 local d_rc2_D = r(mu_2) - r(mu_1);
 local n1_rc2_D = r(N_1);
 local n2_rc2_D = r(N_2);
 local t_rc2_D = -r(t);
ttest npat_wnom1 if party == 100 & (type == "2 joiner" | type == "1 leaver"), by(type);
 local m1_npat_D = r(mu_1);
 local m2_npat_D = r(mu_2);
 local d_npat_D = r(mu_2) - r(mu_1);
 local n1_npat_D = r(N_1);
 local n2_npat_D = r(N_2);
 local t_npat_D = -r(t);
ttest npat_linp if party == 100 & (type == "2 joiner" | type == "1 leaver"), by(type);
 local m1_linp_D = r(mu_1);
 local m2_linp_D = r(mu_2);
 local d_linp_D = r(mu_2) - r(mu_1);
 local n1_linp_D = r(N_1);
 local n2_linp_D = r(N_2);
 local t_linp_D = -r(t);
foreach i in trichotomous nonexpanded_v1 nonexpanded_v2 nonexpanded_v3 nonexpanded_v4 {;
	if "`i'" == "expanded" {;
		local t e;
	};
	if "`i'" == "trichotomous" {;
		local t t;
	};
	if "`i'" == "nonexpanded_v1" {;
		local t n1;
	};
	if "`i'" == "nonexpanded_v2" {;
		local t n2;
	};
	if "`i'" == "nonexpanded_v3" {;
		local t n3;
	};
	if "`i'" == "nonexpanded_v4" {;
		local t n4;
	};
	ttest npat_wnom1_`i' if party == 100 & (type == "2 joiner" | type == "1 leaver"), by(type);
	 local m1_npat_D_`t' = r(mu_1);
	 local m2_npat_D_`t' = r(mu_2);
	 local d_npat_D_`t' = r(mu_2) - r(mu_1);
	 local n1_npat_D_`t' = r(N_1);
	 local n2_npat_D_`t' = r(N_2);
	 local t_npat_D_`t' = -r(t);
};
foreach i in defense econ eduh envir other social {;
	ttest npat_linp_`i' if party == 100 & (type == "2 joiner" | type == "1 leaver"), by(type);
	 local m1_`i'_D = r(mu_1);
	 local m2_`i'_D = r(mu_2);
	 local d_`i'_D = r(mu_2) - r(mu_1);
	 local n1_`i'_D = r(N_1);
	 local n2_`i'_D = r(N_2);
	 local t_`i'_D = -r(t);
};
use npat_scores_dataset, clear;
foreach i in defense econ eduh envir other social {;
  sum npat_N_`i';
  local n_`i' = r(max);
};
local q_defense = 4;
local q_econ    = 8;
local q_eduh    = 5;
local q_envir   = 3;
local q_other   = 7;
local q_social  = 6;


/***** MAKE TABLE 2 *****/

quietly {;
	capture log close;
	log using figures_and_tables/table_t_tests_2.tex, text replace;
	noisily display "\begin{table}[htbp] ";
	noisily display "\centering ";
	noisily display "\begin{threeparttable} ";
	noisily display "\caption{\bf Are New MCs More Extreme than Departing MCs?} ";
	noisily display "\label{table_t_tests_2} ";
	noisily display "\begin{tabular}{lcccccc} ";
	noisily display "\toprule ";
	noisily display "     & Joiner & Leaver & Diff.    &         & \# MCs  & \# MCs  \\ ";
	noisily display "Case & Mean   & Mean   & in Means & t-Stat. & Joining & Leaving \\ [.01in] ";
	noisily display "\midrule ";
	noisily display "\multicolumn{7}{l}{\it Republicans} \\ [.01in] ";
	noisily display "Roll-Call Score, all MCs       & " %5.3f `m2_rc1_R'  " & " %5.3f `m1_rc1_R'  " & " %5.3f `d_rc1_R'  " & " %5.3f `t_rc1_R'  " & " %3.0f `n2_rc1_R'  " & " %3.0f `n1_rc1_R'  " \\ ";  
	noisily display "Roll-Call Score, MCs with NPAT & " %5.3f `m2_rc2_R'  " & " %5.3f `m1_rc2_R'  " & " %5.3f `d_rc2_R'  " & " %5.3f `t_rc2_R'  " & " %3.0f `n2_rc2_R'  " & " %3.0f `n1_rc2_R'  " \\ ";  
	noisily display "NPAT Score, MCs with NPAT      & " %5.3f `m2_npat_R' " & " %5.3f `m1_npat_R' " & " %5.3f `d_npat_R' " & " %5.3f `t_npat_R' " & " %3.0f `n2_npat_R' " & " %3.0f `n1_npat_R' " \\ ";  
	noisily display "\midrule ";
	noisily display "\multicolumn{7}{l}{\it Democrats} \\ [.01in] "; 
	noisily display "Roll-Call Score, all MCs       & " %5.3f `m2_rc1_D'  " & " %5.3f `m1_rc1_D'  " & " %5.3f `d_rc1_D'  " & " %5.3f `t_rc1_D'  " & " %3.0f `n2_rc1_D'  " & " %3.0f `n1_rc1_D'  " \\ ";  
	noisily display "Roll-Call Score, MCs with NPAT & " %5.3f `m2_rc2_D'  " & " %5.3f `m1_rc2_D'  " & " %5.3f `d_rc2_D'  " & " %5.3f `t_rc2_D'  " & " %3.0f `n2_rc2_D'  " & " %3.0f `n1_rc2_D'  " \\ ";  
	noisily display "NPAT Score, MCs with NPAT      & " %5.3f `m2_npat_D' " & " %5.3f `m1_npat_D' " & " %5.3f `d_npat_D' " & " %5.3f `t_npat_D' " & " %3.0f `n2_npat_D' " & " %3.0f `n1_npat_D' " \\ ";  
	noisily display "\bottomrule ";
	noisily display "\end{tabular}";
	noisily display "\end{threeparttable} ";
	noisily display "\end{table} ";
	log close;
};


/***** MAKE APPENDIX TABLE A.7 (LINEAR CONSERVATIVE PROBABILITY SCORES) *****/

quietly {;
	capture log close;
	log using appendix_figures_and_tables/table_t_tests_2_linp.tex, text replace;
	noisily display "\begin{table}[htbp] ";
	noisily display "\centering ";
	noisily display "\begin{threeparttable} ";
	noisily display "\caption{\bf Are New MCs More Extreme than Departing MCs? \\ (Linear Conservative Probability Scores)} ";
	noisily display "\label{table_t_tests_2_linp} ";
	noisily display "\begin{tabular}{lcccccc} ";
	noisily display "\toprule ";
	noisily display "     & Joiner & Leaver & Diff.    &         & \# MCs  & \# MCs  \\ ";
	noisily display "Case & Mean   & Mean   & in Means & t-Stat. & Joining & Leaving \\ [.01in] ";
	noisily display "\midrule ";
	noisily display "\multicolumn{7}{l}{\it Republicans} \\ [.01in] "; 
	noisily display "NPAT Score, MCs with NPAT      & " %5.3f `m2_linp_R' " & " %5.3f `m1_linp_R' " & " %5.3f `d_linp_R' " & " %5.3f `t_linp_R' " & " %3.0f `n2_linp_R' " & " %3.0f `n1_linp_R' " \\ ";  
	noisily display "\midrule ";
	noisily display "\multicolumn{7}{l}{\it Democrats} \\ [.01in] "; 
	noisily display "NPAT Score, MCs with NPAT      & " %5.3f `m2_linp_D' " & " %5.3f `m1_linp_D' " & " %5.3f `d_linp_D' " & " %5.3f `t_linp_D' " & " %3.0f `n2_linp_D' " & " %3.0f `n1_linp_D' " \\ ";  
	noisily display "\bottomrule ";
	noisily display "\end{tabular}";
	noisily display "\end{threeparttable} ";
	noisily display "\end{table} ";
	log close;
};


/***** MAKE TABLE 4 *****/

quietly {;
    capture log close;
    log using figures_and_tables/table_t_tests_4.tex, text replace;

    noisily display "\begin{table}[htbp] ";
    noisily display "\centering ";
    noisily display "\caption{\bf Are New MCs More Extreme than Departing MCs? 
      \\ NPAT Scores on Different Issue Bundles 
      \\ (Linear Conservative Probability Scores)} ";
    noisily display "\label{table_t_tests_4} ";
    noisily display "\resizebox{\textwidth}{!}{ ";
    noisily display "\begin{tabular}{lcccccccc} ";
    noisily display "\toprule ";
    noisily display "     & Joiner & Leaver & Diff.    &         & \# MCs  & \# MCs  & \# Total & \# Unique \\ ";
    noisily display "Case & Mean   & Mean   & in Means & t-Stat. & Joining & Leaving & Items	 & Questions \\ [.01in] ";

    noisily display "\midrule ";
    noisily display "\multicolumn{8}{l}{\it Republicans} \\ [.01in] "; 
    noisily display "Economic            & " %6.3f `m2_econ_R'    " & " %6.3f `m1_econ_R'    " & " %6.3f `d_econ_R'    " & " %6.3f `t_econ_R'    " & " %3.0f `n2_econ_R'    " & " %3.0f `n1_econ_R'    " & " %1.0f `n_econ'    " & " %1.0f `q_econ'    " \\ ";
    noisily display "Education \& health & " %6.3f `m2_eduh_R'    " & " %6.3f `m1_eduh_R'    " & " %6.3f `d_eduh_R'    " & " %6.3f `t_eduh_R'    " & " %3.0f `n2_eduh_R'    " & " %3.0f `n1_eduh_R'    " & " %1.0f `n_eduh'    " & " %1.0f `q_eduh'    " \\ ";
    noisily display "Environmental       & " %6.3f `m2_envir_R'   " & " %6.3f `m1_envir_R'   " & " %6.3f `d_envir_R'   " & " %6.3f `t_envir_R'   " & " %3.0f `n2_envir_R'   " & " %3.0f `n1_envir_R'   " & " %1.0f `n_envir'   " & " %1.0f `q_envir'   " \\ ";  
    noisily display "National defense    & " %6.3f `m2_defense_R' " & " %6.3f `m1_defense_R' " & " %6.3f `d_defense_R' " & " %6.3f `t_defense_R' " & " %3.0f `n2_defense_R' " & " %3.0f `n1_defense_R' " & " %1.0f `n_defense' " & " %1.0f `q_defense' " \\ ";  
    noisily display "Social \& cultural  & " %6.3f `m2_social_R'  " & " %6.3f `m1_social_R'  " & " %6.3f `d_social_R'  " & " %6.3f `t_social_R'  " & " %3.0f `n2_social_R'  " & " %3.0f `n1_social_R'  " & " %1.0f `n_social'  " & " %1.0f `q_social'  " \\ ";  
    noisily display "Other               & " %6.3f `m2_other_R'   " & " %6.3f `m1_other_R'   " & " %6.3f `d_other_R'   " & " %6.3f `t_other_R'   " & " %3.0f `n2_other_R'   " & " %3.0f `n1_other_R'   " & " %1.0f `n_other'   " & " %1.0f `q_other'   " \\ ";  
  
    noisily display "\midrule ";
    noisily display "\multicolumn{8}{l}{\it Democrats} \\ [.01in] "; 
    noisily display "Economic            & " %6.3f `m2_econ_D'    " & " %6.3f `m1_econ_D'    " & " %6.3f `d_econ_D'    " & " %6.3f `t_econ_D'    " & " %3.0f `n2_econ_D'    " & " %3.0f `n1_econ_D'    " & " %1.0f `n_econ'    " & " %1.0f `q_econ'    " \\ ";
    noisily display "Education \& health & " %6.3f `m2_eduh_D'    " & " %6.3f `m1_eduh_D'    " & " %6.3f `d_eduh_D'    " & " %6.3f `t_eduh_D'    " & " %3.0f `n2_eduh_D'    " & " %3.0f `n1_eduh_D'    " & " %1.0f `n_eduh'    " & " %1.0f `q_eduh'    " \\ ";
    noisily display "Environmental       & " %6.3f `m2_envir_D'   " & " %6.3f `m1_envir_D'   " & " %6.3f `d_envir_D'   " & " %6.3f `t_envir_D'   " & " %3.0f `n2_envir_D'   " & " %3.0f `n1_envir_D'   " & " %1.0f `n_envir'   " & " %1.0f `q_envir'   " \\ ";  
    noisily display "National defense    & " %6.3f `m2_defense_D' " & " %6.3f `m1_defense_D' " & " %6.3f `d_defense_D' " & " %6.3f `t_defense_D' " & " %3.0f `n2_defense_D' " & " %3.0f `n1_defense_D' " & " %1.0f `n_defense' " & " %1.0f `q_defense' " \\ ";  
    noisily display "Social \& cultural  & " %6.3f `m2_social_D'  " & " %6.3f `m1_social_D'  " & " %6.3f `d_social_D'  " & " %6.3f `t_social_D'  " & " %3.0f `n2_social_D'  " & " %3.0f `n1_social_D'  " & " %1.0f `n_social'  " & " %1.0f `q_social'  " \\ ";  
    noisily display "Other               & " %6.3f `m2_other_D'   " & " %6.3f `m1_other_D'   " & " %6.3f `d_other_D'   " & " %6.3f `t_other_D'   " & " %3.0f `n2_other_D'   " & " %3.0f `n1_other_D'   " & " %1.0f `n_other'   " & " %1.0f `q_other'   " \\ ";  

    noisily display "\bottomrule ";
    noisily display "\end{tabular}";
    noisily display "} ";
    noisily display "\end{table} ";
    log close;
  };


/***** MAKE APPENDIX TABLE A.4 (TRICHOTOMOUS AND 4 VERSIONS OF DICHOTOMOUS CODING OF LIKERT SCALE ITEMS) *****/

quietly {;
  capture log close;
  log using appendix_figures_and_tables/table_t_tests_2_appendix_codings.tex, text replace;

  noisily display "\begin{table}[htbp] ";
  noisily display "\centering ";
  noisily display "\caption{\bf Are New MCs More Extreme than Departing MCs? \\ Alternative Coding Rules for Likert-Scale NPAT Questions} ";
  noisily display "\label{table_t_tests_2_appendix_codings} ";
  noisily display "\resizebox{\textwidth}{!}{ ";
  noisily display "\begin{tabular}{lcccccc} ";
  noisily display "\toprule ";
  noisily display "     & Joiner & Leaver & Diff.    &         & \# MCs  & \# MCs  \\ ";
  noisily display "Case & Mean   & Mean   & in Means & t-Stat. & Joining & Leaving \\ [.01in] ";

  noisily display "\midrule ";
  noisily display "\multicolumn{7}{l}{\it Republicans} \\ [.01in] ";
  noisily display "NPAT Score, MCs with NPAT, Likert-to-Trichot  & " %5.3f `m2_npat_R_t'   " & " %5.3f `m1_npat_R_t'   " & " %5.3f `d_npat_R_t'   " & " %5.3f `t_npat_R_t'   " & " %3.0f `n2_npat_R_t'   " & " %3.0f `n1_npat_R_t'   " \\ ";  
  noisily display "NPAT Score, MCs with NPAT, Likert-to-Binary 1 & " %5.3f `m2_npat_R_n1'  " & " %5.3f `m1_npat_R_n1'  " & " %5.3f `d_npat_R_n1'  " & " %5.3f `t_npat_R_n1'  " & " %3.0f `n2_npat_R_n1'  " & " %3.0f `n1_npat_R_n1'  " \\ ";  
  noisily display "NPAT Score, MCs with NPAT, Likert-to-Binary 2 & " %5.3f `m2_npat_R_n2'  " & " %5.3f `m1_npat_R_n2'  " & " %5.3f `d_npat_R_n2'  " & " %5.3f `t_npat_R_n2'  " & " %3.0f `n2_npat_R_n2'  " & " %3.0f `n1_npat_R_n2'  " \\ ";  
  noisily display "NPAT Score, MCs with NPAT, Likert-to-Binary 3 & " %5.3f `m2_npat_R_n3'  " & " %5.3f `m1_npat_R_n3'  " & " %5.3f `d_npat_R_n3'  " & " %5.3f `t_npat_R_n3'  " & " %3.0f `n2_npat_R_n3'  " & " %3.0f `n1_npat_R_n3'  " \\ ";  
  noisily display "NPAT Score, MCs with NPAT, Likert-to-Binary 4 & " %5.3f `m2_npat_R_n4'  " & " %5.3f `m1_npat_R_n4'  " & " %5.3f `d_npat_R_n4'  " & " %5.3f `t_npat_R_n4'  " & " %3.0f `n2_npat_R_n4'  " & " %3.0f `n1_npat_R_n4'  " \\ ";  

  noisily display "\midrule ";
  noisily display "\multicolumn{7}{l}{\it Democrats} \\ [.01in] "; 
  noisily display "NPAT Score, MCs with NPAT, Likert-to-Trichot  & " %5.3f `m2_npat_D_t'   " & " %5.3f `m1_npat_D_t'   " & " %5.3f `d_npat_D_t'   " & " %5.3f `t_npat_D_t'   " & " %3.0f `n2_npat_D_t'   " & " %3.0f `n1_npat_D_t'   " \\ ";  
  noisily display "NPAT Score, MCs with NPAT, Likert-to-Binary 1 & " %5.3f `m2_npat_D_n1'  " & " %5.3f `m1_npat_D_n1'  " & " %5.3f `d_npat_D_n1'  " & " %5.3f `t_npat_D_n1'  " & " %3.0f `n2_npat_D_n1'  " & " %3.0f `n1_npat_D_n1'  " \\ ";  
  noisily display "NPAT Score, MCs with NPAT, Likert-to-Binary 2 & " %5.3f `m2_npat_D_n2'  " & " %5.3f `m1_npat_D_n2'  " & " %5.3f `d_npat_D_n2'  " & " %5.3f `t_npat_D_n2'  " & " %3.0f `n2_npat_D_n2'  " & " %3.0f `n1_npat_D_n2'  " \\ ";  
  noisily display "NPAT Score, MCs with NPAT, Likert-to-Binary 3 & " %5.3f `m2_npat_D_n3'  " & " %5.3f `m1_npat_D_n3'  " & " %5.3f `d_npat_D_n3'  " & " %5.3f `t_npat_D_n3'  " & " %3.0f `n2_npat_D_n3'  " & " %3.0f `n1_npat_D_n3'  " \\ ";  
  noisily display "NPAT Score, MCs with NPAT, Likert-to-Binary 4 & " %5.3f `m2_npat_D_n4'  " & " %5.3f `m1_npat_D_n4'  " & " %5.3f `d_npat_D_n4'  " & " %5.3f `t_npat_D_n4'  " & " %3.0f `n2_npat_D_n4'  " & " %3.0f `n1_npat_D_n4'  " \\ ";  

  noisily display "\bottomrule ";
  noisily display "\end{tabular}";
  noisily display "} ";
  noisily display "\end{table} ";
  log close;
};


/***** MAKE APPENDIX TABLE A.8 SHOWING POLARIZATION DUE TO REPLACEMENT FOR EACH ISSUE SEPARATELY *****/

use tmp1, clear;
gen Rjoiner = (type=="2 joiner" & party==200) & party!=328;
gen Rleaver = (type=="1 leaver" & party==200) & party!=328;
gen Djoiner = (type=="2 joiner" & party==100) & party!=328;

foreach i in defense econ eduh envir other social {;
	ttest npat_linp_`i' if type == "1 leaver", by(party);
	 local m1_`i'_D_leaver = r(mu_1);
	 local m2_`i'_R_leaver = r(mu_2);
	 local d_`i'_leaver = r(mu_2) - r(mu_1);
	 local n1_`i'_D_leaver = r(N_1);
	 local n2_`i'_R_leaver = r(N_2);
	 local t_`i'_leaver = -r(t);
  	ttest npat_linp_`i' if type == "2 joiner", by(party);
	 local m1_`i'_D_joiner = r(mu_1);
	 local m2_`i'_R_joiner = r(mu_2);
	 local d_`i'_joiner = r(mu_2) - r(mu_1);
	 local n1_`i'_D_joiner = r(N_1);
	 local n2_`i'_R_joiner = r(N_2);
	 local t_`i'_joiner = -r(t);
	 local d_`i'_joiner_leaver = `d_`i'_joiner' - `d_`i'_leaver';
  	reg npat_linp_`i' Rjoiner Rleaver Djoiner;
	 test (Rjoiner - Rleaver) = Djoiner;
	 local F_`i'_joiner_leaver = r(F);
	 local p_`i'_joiner_leaver = r(p);
};

quietly {;
  capture log close;
  log using appendix_figures_and_tables/table_t_tests_5.tex, text replace;

  noisily display "\begin{table}[htbp] ";
  noisily display "\centering ";
  noisily display "\caption{\bf In What Issue Bundles is Polarization Growing through Replacement? 
    \\ (Linear Conservative Probability Scores)} ";
  noisily display "\label{table_t_tests_5} ";
  noisily display "\begin{tabular}{lccccc} ";
  noisily display "\toprule ";
  noisily display "                    & Party Gap  & Party Gap   & Diff. in   &  p-value      \\ ";
  noisily display "Issue Bundle        & Joiners    & Leavers     & Party Gaps & from F-test \\ [.01in] ";
  noisily display "\midrule ";
  noisily display "Economic            & " %6.3f  `d_econ_joiner'    " & " %6.3f `d_econ_leaver'    " & " %6.3f `d_econ_joiner_leaver'    " & " %6.3f `p_econ_joiner_leaver'    " \\ ";
  noisily display "Education \& health & " %6.3f  `d_eduh_joiner'    " & " %6.3f `d_eduh_leaver'    " & " %6.3f `d_eduh_joiner_leaver'    " & " %6.3f `p_eduh_joiner_leaver'    " \\ ";
  noisily display "Environmental       & " %6.3f  `d_envir_joiner'   " & " %6.3f `d_envir_leaver'   " & " %6.3f `d_envir_joiner_leaver'   " & " %6.3f `p_envir_joiner_leaver'   " \\ ";  
  noisily display "National defense    & " %6.3f  `d_defense_joiner' " & " %6.3f `d_defense_leaver' " & " %6.3f `d_defense_joiner_leaver' " & " %6.3f `p_defense_joiner_leaver' " \\ ";  
  noisily display "Social \& cultural  & " %6.3f  `d_social_joiner'  " & " %6.3f `d_social_leaver'  " & " %6.3f `d_social_joiner_leaver'  " & " %6.3f `p_social_joiner_leaver'  " \\ ";  
  noisily display "Other               & " %6.3f  `d_other_joiner'   " & " %6.3f `d_other_leaver'   " & " %6.3f `d_other_joiner_leaver'   " & " %6.3f `p_other_joiner_leaver'   " \\ ";  
  noisily display "\bottomrule [.01in]";
  noisily display "\multicolumn{6}{l}{\footnotesize Party gap joiners is the difference in means between Republican joiners and} \\";
  noisily display "\multicolumn{6}{l}{\footnotesize Democratic joiners: $(\bar{R}_\text{joiner}-\bar{D}_\text{joiner})$. Party gap leavers is the difference in means} \\"; 
  noisily display "\multicolumn{6}{l}{\footnotesize between Republican leavers and Democratic leavers: $(\bar{R}_\text{leaver}-\bar{D}_\text{leaver})$. The difference} \\"; 
  noisily display "\multicolumn{6}{l}{\footnotesize in party gaps is the difference in these differences: $(\bar{R}_\text{joiner}-\bar{D}_\text{joiner})-(\bar{R}_\text{leaver}-\bar{D}_\text{leaver})$.} \\";
  noisily display "\end{tabular}";
  noisily display "\end{table} ";
  log close;

};


/***** MAKE TABLE 3 *****/

use rollcall_scores_dataset, clear;
keep if type == "0 stayer";
keep if (year == 1996 | year == 2008);
egen x = count(rc_dwnom1), by(idno);
tab x;
keep if x == 2;

ttest rc_dwnom1 if party == 200, by(year);
local m1_all_stayer_1_R = r(mu_1);
local m2_all_stayer_1_R = r(mu_2);
local d_all_stayer_1_R = r(mu_2) - r(mu_1);
local n_all_stayer_1_R = r(N_1);
local t_all_stayer_1_R = -r(t);

ttest rc_dwnom1 if party == 200 & npat_id != "", by(year);
local m1_all_stayer_2_R = r(mu_1);
local m2_all_stayer_2_R = r(mu_2);
local d_all_stayer_2_R = r(mu_2) - r(mu_1);
local n_all_stayer_2_R = r(N_1);
local t_all_stayer_2_R = -r(t);

ttest rc_dwnom1 if party == 100, by(year);
local m1_all_stayer_1_D = r(mu_1);
local m2_all_stayer_1_D = r(mu_2);
local d_all_stayer_1_D = r(mu_2) - r(mu_1);
local n_all_stayer_1_D = r(N_1);
local t_all_stayer_1_D = -r(t);

ttest rc_dwnom1 if party == 100 & npat_id != "", by(year);
local m1_all_stayer_2_D = r(mu_1);
local m2_all_stayer_2_D = r(mu_2);
local d_all_stayer_2_D = r(mu_2) - r(mu_1);
local n_all_stayer_2_D = r(N_1);
local t_all_stayer_2_D = -r(t);

quietly {;
  capture log close;
  log using figures_and_tables/table_rollcall_3.tex, text replace;

  noisily display "\begin{table}[htbp] ";
  noisily display "\centering ";
  noisily display "\begin{threeparttable} ";
  noisily display "\caption{\bf Within-Member Changes in Roll-Call Scores \\ for MCs Serving for Entire 1996-2008 Period} ";
  noisily display "\label{table_rollcall_3} ";
  noisily display "\begin{tabular}{lccccc} ";
  noisily display "\toprule ";
  noisily display "     & 1996  & 2008  & Diff.    &         &        \\ ";
  noisily display "Case & Mean  & Mean  & in Means & t-Stat. & \# MCs \\ [.01in] ";

  noisily display "\midrule ";
  noisily display "\multicolumn{6}{l}{\it Republicans} \\ [.01in] "; 
  noisily display "All MCs       & " %5.3f `m1_all_stayer_1_R' " & " %5.3f `m2_all_stayer_1_R' " & " %5.3f `d_all_stayer_1_R' " & " %5.3f `t_all_stayer_1_R' " & " %3.0f `n_all_stayer_1_R' " \\ ";  
  noisily display "MCs with NPAT & " %5.3f `m1_all_stayer_2_R' " & " %5.3f `m2_all_stayer_2_R' " & " %5.3f `d_all_stayer_2_R' " & " %5.3f `t_all_stayer_2_R' " & " %3.0f `n_all_stayer_2_R' " \\ ";  

  noisily display "\midrule ";
  noisily display "\multicolumn{6}{l}{\it Democrats} \\ [.01in] "; 
  noisily display "All MCs       & " %5.3f `m1_all_stayer_1_D' " & " %5.3f `m2_all_stayer_1_D' " & " %5.3f `d_all_stayer_1_D' " & " %5.3f `t_all_stayer_1_D' " & " %3.0f `n_all_stayer_1_D' " \\ ";  
  noisily display "MCs with NPAT & " %5.3f `m1_all_stayer_2_D' " & " %5.3f `m2_all_stayer_2_D' " & " %5.3f `d_all_stayer_2_D' " & " %5.3f `t_all_stayer_2_D' " & " %3.0f `n_all_stayer_2_D' " \\ ";  

  noisily display "\bottomrule ";
  noisily display "\end{tabular}";
  noisily display "\end{threeparttable} ";
  noisily display "\end{table} ";
  log close;
};

capture erase tmp1.dta;


/***** MAKE FIGURES A.1 & A.2 *****/

import delimited using wnom_estimates/cutpoints_expanded.csv, clear varn(1);
keep npat_question midpoint1d;
rename midpoint1d midpoint1d_ca;
tempfile temp_ca;
save `temp_ca';

import delimited using wnom_estimates/cutpoints_expanded_allQs.csv, clear varn(1);
keep npat_question midpoint1d;
rename midpoint1d midpoint1d_1yr;

merge 1:1 npat_question using `temp_ca';
destring midpoint*, replace i("NA");

/* Figure A.1 - Distribution of cutpoints for constant agenda items */
set scheme s1color;
hist midpoint1d_ca, fcol(navy) lcol(black) bin(10) xsize(8) ysize(6) 
	xlabel(,labsize(large)) xtitle(Midpoint,size(large)) ytitle(,size(large)) 
	ylabel(,angle(horizontal) labsize(large));
graph export "appendix_figures_and_tables/cutpoints_constant_agenda.pdf", replace;

/* Figure A.2 - Distribution of cutpoints for non-constant agenda items */
hist midpoint1d_1yr if _merge==1, fcol(navy) lcol(black) bin(10) xsize(8) ysize(6) 
	xlabel(,labsize(large)) xtitle(Midpoint,size(large)) ytitle(,size(large)) 
	ylabel(,angle(horizontal) labsize(large));
graph export "appendix_figures_and_tables/cutpoints_nonCA_items.pdf", replace;

/* K-S test */
import delimited using wnom_estimates/cutpoints_expanded_allQs.csv, clear varn(1);
keep npat_question midpoint1d;
rename midpoint1d midpoint1d_1yr;
append using `temp_ca';
destring midpoint*, replace i("NA");
gen agenda = "CA" if !missing(midpoint1d_ca);
replace agenda = "all" if !missing(midpoint1d_1yr);
gen midpt = midpoint1d_1yr;
replace midpt = midpoint1d_ca if missing(midpt);
quietly ksmirnov midpt, by(agenda);
local ks_p : display %4.3f r(p);
file open myfile using "appendix_figures_and_tables/K-S_p.tex", write replace;
file write myfile 
"$`ks_p'$" _n;
file close myfile;


/***** MAKE TABLE A.5 *****/

use rollcall_scores_dataset, clear;
keep idno rc_csnom1;
duplicates drop;
tempfile temp_csnom;
save `temp_csnom';

use npat_scores_dataset, clear;
merge m:1 idno using `temp_csnom';

corr rc_csnom1 npat_wnom1;
	local r_overall : display %4.3f r(rho);
	local N_overall = r(N);
corr rc_csnom1 npat_wnom1 if party=="D";
	local r_Dems : display %4.3f r(rho);
	local N_Dems = r(N);
corr rc_csnom1 npat_wnom1 if party=="R";
	local r_Reps : display %4.3f r(rho);
	local N_Reps = r(N);
	
file open myfile using "appendix_figures_and_tables/table_within_party_corr.tex", write replace;
file write myfile 
"\begin{table}[htbp] " _n 
"\centering " _n 
"\begin{threeparttable} " _n 
"\caption{\bf Correlation Between NPAT Scores and NOMINATE}" _n 
"\label{table_within_party_corr} " _n 
"\begin{tabular}{lcc} " _n 
"\toprule " _n 
"Case & Corr. Coef. & \# Obs. \\ [.01in] " _n 
"\midrule " _n 
"\midrule " _n 
"Overall & `r_overall' & `N_overall' \\" _n 
"Democrats & `r_Dems' & `N_Dems'  \\" _n 
"Republicans & `r_Reps' & `N_Reps' \\" _n 
"\bottomrule " _n 
"\end{tabular}" _n 
"\end{threeparttable} " _n 
"\end{table} " _n ;
file close myfile;


/***** MAKE FIGURE A.3 *****/

import delimited using wnom_estimates/cutpoints_expanded.csv, clear varn(1);
destring mid* spread*, replace i("NA");
drop correct* wrong* gmp pre;
tempfile temp_cutpts;
save `temp_cutpts';

import delimited using wnom_estimates/iterative_cutpoints_96-00_vs_02-08.csv, clear varn(1);
destring midpt* spread*, replace i("NA");
merge 1:1 npat_question using `temp_cutpts';
drop _merge;

gen abs_diff = abs(midpt1d_0208 - midpt1d_9600);

tw(scatter midpt1d_0208 midpt1d_9600, 
		   mc(black%60) mlc(none) plotregion(lw(0)) ylabel(-1(.2)1) xsize(8) ysize(6) 
		   xlabel(-1(.2)1) xtitle("Midpoint 1996-2000") ytitle("Midpoint 2002-2008"))
  (line midpt1d_0208 midpt1d_0208, col(gray)) 
  (line midpt1d_9600 midpt1d_9600, col(gray)), 
  legend(off);
graph export "appendix_figures_and_tables/iterative_cutpoints.pdf", replace;

/* paired t test of no difference*/
quietly ttest midpt1d_9600==midpt1d_0208;
	local midpt_p : display %4.3f r(p);
file open myfile using "appendix_figures_and_tables/midpt_p.tex", write replace;
file write myfile 
"$`midpt_p'$" _n;
file close myfile;


/***** MAKE FIGURE A.7 *****/

import delimited using wnom_estimates/stateleg_npat_1996-1998.csv, clear;
keep state year lastname firstname id party npat_wnom1;
rename npat_wnom1 npat_wnom_;
reshape wide npat_wnom_, i(id) j(year);
sort npat_wnom_1996 npat_wnom_1998;
scatter npat_wnom_1998 npat_wnom_1996 npat_wnom_1996, ms(i i) mlab(party) 
	mlabpos(0 0) c(. l) lcolor(gs0 gs10) mcolor(gs0 gs10) mlabcolor(gs0 gs10) 
	plotregion(style(none)) graphregion(fcolor(white) lcolor(white)) 
	xtitle(Score in 1996) ytitle(Score in 1998)  
	xlabel(`xylabels') ylabel(`xylabels', nogrid)
	xscale(range(`min12' `max12')) yscale(range(`min12' `max12')) 
	legend(off) aspectratio(1);
graph export "appendix_figures_and_tables/state_leg_NPAT_1998_vs_1996_wnom.pdf", replace;


/***** MAKE FIGURE 6 *****/

use H95_113_codes, clear;
keep if cong>94;

recode pelt* (4 3 2=1)  (71  = 61) (72=62) (10 11 20 90 = .) ;

label define peltzman 1 "Budget and Regulation" 5 "Social Policy" 61 "Defense" 
	62 "Foreign Policy" 8 "Govt Organization" 9 "Internal/Procedural" ;
label values pelt1 peltzman;

bys cong: egen total_votes = count(cong);
egen cong_issue = group(pelt1 cong);
bys cong_issue: egen issues_votes = count(cong);
gen issue_percent = issues_votes/total_votes;

duplicates drop cong_issue,force;

tabstat issue_percent, by(pelt1 ) stat(mean min max);
 
line issue_percent cong, by(pelt1, note("") ixaxes) c(l) lcolor(dknavy) xtitle("")
ytitle("Proportion of Total Votes") xlab(97 "1980" 102 "1990" 107 "2000" 112 "2010")
xline(103.5(.01)111.5, lcolor(gray*.2)  lwidth(1)) plotregion(style(none) fcolor(white))
graphregion(fcolor(white) lcolor(white)) subtitle(, fcolor(none) lstyle(none));

graph export "figures_and_tables/peltzman_issues_by_cong.pdf", replace;



/******************************/
/***** IN-TEXT QUANTITIES *****/
/******************************/

/*** NPAT respondents ***/
use npat_scores_dataset, clear;

/* how many unique candidates responded at least twice from 1996-2008 */
bys npat_id (year): gen at_least_two_surveys = 1 if _n==2;
count if at_least_two_surveys==1;
local unique_two_surveys = r(N);

/* how many surveys in total for candidates who filled at least two */
bys npat_id (year): egen max_at_least_two_surveys = max(at_least_two_surveys);
count if max_at_least_two_surveys==1;
local total_two_surveys = r(N);

/* average number of surveys for candidates who filled out NPAT at least twice */
di %4.1f `total_two_surveys' / `unique_two_surveys';

/* how many unique candidates responded twice and served in congress */
replace at_least_two_surveys = . if missing(idno);
count if at_least_two_surveys==1;
local cong_unique_two_surveys = r(N);

/* how many surveys in total for candidates who filled at least two and served in congress */
drop max_at_least_two_surveys;
bys npat_id (year): egen max_at_least_two_surveys = max(at_least_two_surveys);
count if max_at_least_two_surveys==1;
local cong_total_two_surveys = r(N);

/* average number of surveys for candidates who filled out NPAT at least twice and served in congress */
di %4.1f `cong_total_two_surveys' / `cong_unique_two_surveys';

/* share of unique legislators elected to serve in the house, 105th-111th congresses */
use rollcall_scores_dataset, clear;
keep if congress>=105 & congress<=111;
bys bioguide_id (congress): gen unique_member = 1 if _n==1;
quietly count if unique_member==1;
local unique_members = r(N);
di %4.0f (`cong_unique_two_surveys' / `unique_members') * 100;

/* share of unique legislators who served multiple terms in house during 105th-111th congresses */
bys bioguide_id (congress): gen unique_member_mult_terms = 1 if _n==2;
quietly count if unique_member_mult_terms==1;
local unique_member_mult_terms = r(N);
di %4.0f (`cong_unique_two_surveys' / `unique_member_mult_terms') * 100;


/*** missingness in NPAT surveys ***/
use npat_missingness, clear;
/* share of surveys with 0% missingness on constant agenda items */
quietly count;
local tot_surveys = r(N);
quietly count if pct_miss==0;
local zero_miss = r(N);
di %4.0f (`zero_miss' / `tot_surveys') * 100;

/* share of surveys with missingness for 5% or fewer items */
quietly count if pct_miss<=.05;
local miss_5pct = r(N);
di %4.0f (`miss_5pct' / `tot_surveys') * 100;

/* overall percent missingness */
quietly sum pct_miss;
di %4.2f r(mean);

/* share of surveys dropped with missingness >= 33.33% */
quietly count if pct_miss>=.3333 & pct_miss<.;
local dropped_miss = r(N);
di %4.0f (`dropped_miss' / `tot_surveys') * 100;

/* percent missingness after imposing missingness threshold */
quietly sum pct_miss if pct_miss<.3333;
di %4.2f r(mean);

/* percent missingness in roll-call votes, 105th-111th congresses */
forval i =105/111{;
	import delimited using H`i'_votes.csv, clear;
	drop prob;
	if `i'==105{;
		tempfile temp_rolls;
		save `temp_rolls';
	};
	if `i'!=105{;
		append using `temp_rolls', force;
		save `temp_rolls', replace;
	};
};
gen _voted = 1 if inlist(cast_code,1,6);
replace _voted = 0 if inlist(cast_code,7,9);
bys congress: egen max_rollnumber = max(rollnumber);
collapse (sum) _voted (mean) max_rollnumber, by(icpsr congress);
gen share_missing = 1 - _voted / max_rollnumber;
quietly sum share_missing;
di %4.2f r(mean);


/*** support for defense intelligence operations ***/
/* support for increase in spending on defense intelligence operations */
use matrices_for_scaling/npat_expanded_allQs.dta, clear;
/* 1996-2000 */
quietly count if (defense82_1==1 | defense82_2==1) & inlist(year,1996,1998,2000);
local support_dei_9600 = r(N);
quietly count if !missing(defense82_1) & inlist(year,1996,1998,2000);
local tot_9600 = r(N);
di %4.0f (`support_dei_9600' / `tot_9600') * 100;
/* 2002-2006 */
quietly count if (defense92_1==1 | defense92_2==1) & inlist(year,2002,2004,2006);
local support_dei_0206 = r(N);
quietly count if !missing(defense92_1) & inlist(year,2002,2004,2006);
local tot_0206 = r(N);
di %4.0f (`support_dei_0206' / `tot_0206') * 100;

/* within-candidate change in support for def intel operations, 2000-2002 */
gen support_dio_02 = 0 if !missing(defense92_1) & year==2002;
replace support_dio_02 = 1 if (defense92_1==1 | defense92_2==1) & year==2002;
bys npat_id (year): gen support_dio_00 = 0 if !missing(defense82_1[_n-1]) & year[_n-1]==2000;
bys npat_id (year): replace support_dio_00 = 1 if (defense82_1[_n-1]==1 | defense82_2[_n-1]==1) & year[_n-1]==2000;
gen diff_in_support_0200 = support_dio_02 - support_dio_00;
count if diff_in_support_0200==1;
local changed_to_support02 = r(N);
count if !missing(diff_in_support_0200);
local tot_0002 = r(N);
di %4.0f (`changed_to_support02' / `tot_0002') * 100;
count if diff_in_support_0200==-1;

/* within-candidate change in support for def intel operations, 2004-2006 */
gen support_dio_06 = 0 if !missing(defense92_1) & year==2006;
replace support_dio_06 = 1 if (defense92_1==1 | defense92_2==1) & year==2006;
bys npat_id (year): gen support_dio_04 = 0 if !missing(defense92_1[_n-1]) & year[_n-1]==2004;
bys npat_id (year): replace support_dio_04 = 1 if (defense92_1[_n-1]==1 | defense92_2[_n-1]==1) & year[_n-1]==2004;
gen diff_in_support_0604 = support_dio_06 - support_dio_04;
count if diff_in_support_0604==1;
local changed_to_support06 = r(N);
count if !missing(diff_in_support_0604);
local tot_0406 = r(N);
di %4.0f (`changed_to_support06' / `tot_0406') * 100;
count if diff_in_support_0604==-1;
local changed_against06 = r(N);
di %4.0f (`changed_against06' / `tot_0406') * 100;


/*** support for withdrawing troops from iraq ***/
/* support for withdrawing troops in 2004 */
tab intl_pol03_YUN_Y if year==2004;
/* support for withdrawing troops in 2006 */
tab intl_pol03_YUN_Y if year==2006;
/* within candidate change, 2004-2006 */
gen support_withdraw_06 = intl_pol03_YUN_Y==1 if !missing(intl_pol03_YUN_Y) & year==2006;
gen against_withdraw_06 = intl_pol03_YUN_N==1 if !missing(intl_pol03_YUN_N) & year==2006;
bys npat_id (year): gen support_withdraw_04 = intl_pol03_YUN_Y[_n-1]==1 if !missing(intl_pol03_YUN_Y[_n-1]) & year[_n-1]==2004;
bys npat_id (year): gen against_withdraw_04 = intl_pol03_YUN_N[_n-1]==1 if !missing(intl_pol03_YUN_N[_n-1]) & year[_n-1]==2004;
gen diff_in_supportwithdraw_0604 = support_withdraw_06 - support_withdraw_04;
tab diff_in_supportwithdraw_0604;
gen diff_in_againstwithdraw_0604 = against_withdraw_06 - against_withdraw_04;
tab diff_in_againstwithdraw_0604;

/*** tax policy, raise taxes on $150k+ households ***/
/* support raising taxes on high-income households, 1996-2000 */
quietly count if (taxes04_1==1 | taxes04_2==1) & inlist(year,1996,1998,2000);
local support_raise100k_9600 = r(N);
quietly count if !missing(taxes04_1) & inlist(year,1996,1998,2000);
local tot_9600 = r(N);
di %4.0f (`support_raise100k_9600' / `tot_9600') * 100;
/* support raising taxes on high-income households, 2002-2006 */
quietly count if (taxes04_1==1 | taxes04_2==1) & inlist(year,2002,2004,2006);
local support_raise100k_0206 = r(N);
quietly count if !missing(taxes04_1) & inlist(year,2002,2004,2006);
local tot_0206 = r(N);
di %4.0f (`support_raise100k_0206' / `tot_0206') * 100;
/* within-candidate change prior to 2001 */
gen _taxes04 = 0 if !missing(taxes04_1);
forval i = 1/6{;
	replace _taxes04 = `i' if taxes04_`i'==1;
};
gen _taxes04_inc = inlist(_taxes04,1,2) if !missing(_taxes04);
bys npat_id (year): gen diff_taxes_prior01 = _taxes04_inc - _taxes04_inc[_n-1] if inlist(year,2000,1998) &
	year-2==year[_n-1];
tab diff_taxes_prior01;
/* within candidate change, 2000-2002 */
bys npat_id (year): gen diff_taxes_0200 = _taxes04_inc - _taxes04_inc[_n-1] if year==2002 & year[_n-1]==2000;
tab diff_taxes_0200;
/* within candidate change, 2002-2004 */
bys npat_id (year): gen diff_taxes_0402 = _taxes04_inc - _taxes04_inc[_n-1] if year==2004 & year[_n-1]==2002;
tab diff_taxes_0402;
/* within candidate change, 2004-2006 */
bys npat_id (year): gen diff_taxes_0604 = _taxes04_inc - _taxes04_inc[_n-1] if year==2006 & year[_n-1]==2004;
tab diff_taxes_0604;


/*** medicare part d ***/
bys npat_id (year): gen change_support_medpartd = health05_X - health05_X[_n-1] if year-2==year[_n-1] & inlist(year,2002,2004,2006);
tab year change_support_medpartd if year==2002, row;
tab year change_support_medpartd if year==2004, row;
tab year change_support_medpartd if year==2006, row;


/*** minimum wage ***/
bys npat_id (year): gen change_support_minwage = employ_aa06_X - employ_aa06_X[_n-1] if year-2==year[_n-1] & inlist(year,1998,2000,2002,2004,2006);
tab year change_support_minwage if year==1998, row;
tab year change_support_minwage if year==2000, row;
tab year change_support_minwage if year==2006, row;
