#delimit ;
cd "" ;
set linesize 200;

import delimited using wnom_estimates/nominate_expanded, clear;
rename npat_wnom1 npat_wnom1_expanded;
rename npat_wnom2 npat_wnom2_expanded;
save npat_scores_dataset, replace;

foreach type in trichotomous nonexpanded_v1 nonexpanded_v2 nonexpanded_v3 nonexpanded_v4 {;
  import delimited using wnom_estimates/nominate_`type', clear;
  keep npat_id year npat_wnom*;
  rename npat_wnom1 npat_wnom1_`type';
  rename npat_wnom2 npat_wnom2_`type';
  merge 1:1 npat_id year using npat_scores_dataset;
  drop _merge;
  save npat_scores_dataset, replace;
};
sort npat_id year;
order v1 state name npat_id pvs_id idno year office dist party npat_wnom*_expanded npat_wnom*_trichotomous npat_wnom*_nonexpanded_v1 npat_wnom*_nonexpanded_v2 npat_wnom*_nonexpanded_v3 npat_wnom*_nonexpanded_v4;
rename npat_wnom1_expanded npat_wnom1;
rename npat_wnom2_expanded npat_wnom2;
save npat_scores_dataset, replace;

use matrices_for_scaling/npat_expanded, clear;
local defense_q defense* ;
local econ_q    budget15* taxes09* taxes14* taxes16* employ_aa01_X* employ_aa05_X* employ_aa06_X* immigrat01_X ;
local eduh_q    budget04* education02_X education04_X taxes15* health02_X ;
local envir_q   budget05* environ01_X environ08_X ;
local other_q   budget08* budget13* taxes06* taxes08* taxes12* govreform02_X govreform03_X ;
local social_q  education03_X abortion* immigrat02_X guns05_X ;
ds state name idno npat_id pvs_id year office dist party, not;
local all_q = r(varlist);
gen byte repub = (party == "R") if (party == "D" | party == "R");
foreach i of varlist `all_q' {;
  sum `i';
  local max = r(max);
  local min = r(min);
  replace `i' = (`i' - `min')/(`max' - `min');
  corr r `i';
  if r(rho) < 0 {;
    replace `i' = 1 - `i';
  };
};
drop repub;
egen npat_linp = rmean(`all_q');
egen npat_linp_defense = rmean(`defense_q');
egen npat_linp_econ = rmean(`econ_q');
egen npat_linp_eduh = rmean(`eduh_q');
egen npat_linp_envir = rmean(`envir_q');
egen npat_linp_other = rmean(`other_q');
egen npat_linp_social = rmean(`social_q');
egen npat_N = robs(`all_q');
egen npat_N_defense = robs(`defense_q');
egen npat_N_econ = robs(`econ_q');
egen npat_N_eduh = robs(`eduh_q');
egen npat_N_envir = robs(`envir_q');
egen npat_N_other = robs(`other_q');
egen npat_N_social = robs(`social_q');
keep npat_id year npat_linp* npat_N*;
save tmp1, replace;

use npat_scores_dataset, clear;
merge 1:1 npat_id year using tmp1;
drop _merge;
drop pvs_id office dist;
sort npat_id year;
destring idno *nonexpanded_*, i("NA") replace;
save npat_scores_dataset, replace;

erase tmp1.dta;
