# clear the workspace
rm(list=ls())
# set the working directory
setwd("")


# install and open required libraries
install.packages("software/foreign_0.8-84.tar.gz", repos = NULL, type = "source")
install.packages("software/pscl_1.5.5.1.tar.gz", repos = NULL, type = "source")
install.packages("software/wnominate_1.4.tar.gz", repos = NULL, type = "source")
library(foreign)
library(pscl)
library(wnominate)


# set the polarity to Shimkus
poles <- c(90,90)


### EXPANDED, MAIN RESULTS, CONSTANT AGENDA ###
set.seed(60637)
# read in npat data
temp.npat.mat <- read.dta("matrices_for_scaling/npat_expanded.dta")
# create a roll call object
num.cols <- ncol(temp.npat.mat)
legis.party <- as.data.frame(temp.npat.mat$party)
colnames(legis.party) <- "party"
temp.rc <- rollcall(temp.npat.mat[,10:num.cols],
                    legis.data = legis.party)
# 2-dimension wnominate
temp.wnom <- wnominate(temp.rc, dims=2, polarity=poles)
# prepare ideal-points data for output
wnom.1.2 <- round(cbind(temp.wnom$legislators[,"coord1D"],
                  temp.wnom$legislators[,"coord2D"]),2)
colnames(wnom.1.2) <- c("npat_wnom1","npat_wnom2")
wnom.output <- cbind(temp.npat.mat[,1:9],wnom.1.2)
outfile.name <- "wnom_estimates/nominate_expanded.csv"
write.csv(wnom.output,outfile.name)
# prepare cutpoint data for output
cutpoints <- cbind(names(temp.npat.mat[,10:num.cols]),round(temp.wnom$rollcalls,2))
names(cutpoints)[1] <- "npat_question"
outfile.name <- "wnom_estimates/cutpoints_expanded.csv"
write.csv(cutpoints,outfile.name)


### EXPANDED, ALL QUESTIONS ###
### output cutlines for analysis of distribution of 1st-dimension midpoints
# read in npat data
temp.npat.mat <- read.dta("matrices_for_scaling/npat_expanded_allQs.dta")
# create a roll call object
num.cols <- ncol(temp.npat.mat)
legis.party <- as.data.frame(temp.npat.mat$party)
colnames(legis.party) <- "party"
temp.rc <- rollcall(temp.npat.mat[,10:num.cols],
                    legis.data = legis.party)
# 2-dimension wnominate
temp.wnom <- wnominate(temp.rc, dims=2, polarity=poles)
# prepare cutpoint data for output
cutpoints <- cbind(names(temp.npat.mat[,10:num.cols]),round(temp.wnom$rollcalls,2))
names(cutpoints)[1] <- "npat_question"
outfile.name <- "wnom_estimates/cutpoints_expanded_allQs.csv"
write.csv(cutpoints,outfile.name)


### NON-EXPANDED: v1-v4 ###
for(i in 1:4){
  # read in npat data
  temp.npat.mat <- read.dta(paste0("matrices_for_scaling/npat_nonexpanded_v",i,".dta"))
  # create a roll call object
  num.cols <- ncol(temp.npat.mat)
  legis.party <- as.data.frame(temp.npat.mat$party)
  colnames(legis.party) <- "party"
  temp.rc <- rollcall(temp.npat.mat[,10:num.cols],
                      legis.data = legis.party)
  # 2-dimension wnominate
  temp.wnom <- wnominate(temp.rc, dims=2, polarity=poles)
  # prepare ideal-points data for output
  wnom.1.2 <- round(cbind(temp.wnom$legislators[,"coord1D"],
                    temp.wnom$legislators[,"coord2D"]),2)
  colnames(wnom.1.2) <- c("npat_wnom1","npat_wnom2")
  wnom.output <- cbind(temp.npat.mat[,1:9],wnom.1.2)
  outfile.name <- paste0("wnom_estimates/nominate_nonexpanded_v",i,".csv")
  write.csv(wnom.output,outfile.name)
}


### TRICHOTOMOUS ###
# read in npat data
temp.npat.mat <- read.dta("matrices_for_scaling/npat_trichotomous.dta")
# create a roll call object
num.cols <- ncol(temp.npat.mat)
legis.party <- as.data.frame(temp.npat.mat$party)
colnames(legis.party) <- "party"
temp.rc <- rollcall(temp.npat.mat[,10:num.cols],
                    legis.data = legis.party)
# 2-dimension wnominate
temp.wnom <- wnominate(temp.rc, dims=2, polarity=poles)
# prepare ideal-points data for output
wnom.1.2 <- round(cbind(temp.wnom$legislators[,"coord1D"],
                  temp.wnom$legislators[,"coord2D"]),2)
colnames(wnom.1.2) <- c("npat_wnom1","npat_wnom2")
wnom.output <- cbind(temp.npat.mat[,1:9],wnom.1.2)
outfile.name <- paste0("wnom_estimates/nominate_trichotomous.csv")
write.csv(wnom.output,outfile.name)


###################################################
### iterative cutpoints analysis, EXPANDED MAIN ###
###################################################
temp.npat.mat <- read.dta("matrices_for_scaling/npat_expanded.dta")
num.cols <- ncol(temp.npat.mat)
# create matrix to output 
cutpoints <- as.data.frame(matrix(, nrow = num.cols - 9, ncol = 9))
names(cutpoints)[1] <- "npat_question"
names(cutpoints)[2] <- "midpt1d_9600"
names(cutpoints)[3] <- "midpt1d_0208"
names(cutpoints)[4] <- "spread1d_9600"
names(cutpoints)[5] <- "spread1d_0208"
names(cutpoints)[6] <- "midpt2d_9600"
names(cutpoints)[7] <- "midpt2d_0208"
names(cutpoints)[8] <- "spread2d_9600"
names(cutpoints)[9] <- "spread2d_0208"
for(i in 10:num.cols){
  temp.rc.iter <- temp.npat.mat[,i]
  temp.rc.iter.96.00 <- temp.rc.iter
  temp.rc.iter.96.00[temp.npat.mat$year>2000] <- NA
  temp.rc.iter.02.08 <- temp.rc.iter
  temp.rc.iter.02.08[temp.npat.mat$year<2002] <- NA
  temp.name.iter <- names(temp.npat.mat)[i]
  if(i==10){
    temp.npat.mat2 <- cbind(temp.npat.mat[,(i+1):num.cols],temp.rc.iter.96.00,temp.rc.iter.02.08)
  }
  if(i!=10 & i!=num.cols){
    temp.npat.mat2 <- cbind(temp.npat.mat[,10:(i-1)],temp.npat.mat[(i+1):num.cols],
                            temp.rc.iter.96.00,temp.rc.iter.02.08)
  }
  if(i==num.cols){
    temp.npat.mat2 <- cbind(temp.npat.mat[,10:(i-1)],temp.rc.iter.96.00,temp.rc.iter.02.08)
  }
  temp.rc <- rollcall(temp.npat.mat2)
  # 2-dimension wnominate
  temp.wnom <- wnominate(temp.rc, dims=2, polarity=poles)
  # prepare data for output
  temp.cutpoints.iter1 <- round(temp.wnom$rollcalls[(num.cols-9):(num.cols-8),],2)
  temp.cutpoints.iter2 <- c(temp.name.iter,temp.cutpoints.iter1$midpoint1D,temp.cutpoints.iter1$spread1D,
                            temp.cutpoints.iter1$midpoint2D,temp.cutpoints.iter1$spread2D)
  cutpoints[i-9,] <- temp.cutpoints.iter2
  write.csv(cutpoints,"wnom_estimates/iterative_cutpoints_96-00_vs_02-08.csv")
}

##################################
### PLOT CUTLINES THAT SHIFTED ###
##################################

# this section of the code plots the cutlines for any survey items with a
# 1st-dimension midpoint that experienced a shift of at least 0.4 units in 
# either direction.

# read in npat data
temp.npat.mat <- read.dta("matrices_for_scaling/npat_expanded.dta")
# create a roll call object
num.cols <- ncol(temp.npat.mat)
legis.party <- as.data.frame(temp.npat.mat$party=="D")
colnames(legis.party) <- "party"
temp.rc <- rollcall(temp.npat.mat[,10:num.cols],
                    legis.data = legis.party)
# 2-dimension wnominate
temp.wnom <- wnominate(temp.rc, dims=2, polarity=poles)

# plot the cutlines for these shifting items
pdf(file = "appendix_figures_and_tables/iterative_cutlines_shift.pdf", width = 6, height = 6)
plot.coords(temp.wnom, cutline = c(38,49,50,61,62,67,86,96,98), Legend = F,
            main = "Cutlines for Items with Large Shift")
graphics.off()



### state legislative npat 1996-1998
temp.npat.mat <- read.dta("matrices_for_scaling/state_legislators_npat_1996_1998.dta")
# create a roll call object
num.cols <- ncol(temp.npat.mat)
temp.rc <- rollcall(temp.npat.mat[,12:(num.cols-2)])
# 2-dimension wnominate
temp.wnom <- wnominate(temp.rc, dims=2, polarity=c(446,446))
# prepare data for output
wnom.1.2 <- round(cbind(temp.wnom$legislators[,"coord1D"],
                  temp.wnom$legislators[,"coord2D"]),2)
colnames(wnom.1.2) <- c("npat_wnom1","npat_wnom2")
wnom.output <- cbind(temp.npat.mat[,c(1:11,75,76)],wnom.1.2)
write.csv(wnom.output,"wnom_estimates/stateleg_npat_1996-1998.csv")

